#!/bin/tcsh

# ######################################################################
# Demonstration of Mobile IPv6 for global mobility only
# Thierry Ernst
# Version 08.05.01
# ######################################################################
   set MOBI=. 
   set topo=micro-test-20-0		# Topology to load
   set cn_nn=2				# nb of CNs
   set NS=mobiwan			# NS binary
   set cn_seed=1
   set nb_site=8			# nb of Sites where we want Base Stations
   set mt=500				# Movement time interval
   set stop=`expr $mt \* $nb_site \* $cn_nn`	# Stop time

   # NS Congiguration procedures call: 
   set mn_config="set-mobile SITE 1 150.00 150.00 0 0 0.01"

   # Have a BS in each site (same co-ordinates) 
   set bs_config="set-bs RAND { } 8 8 1"

   set cn_config="select-cn SR-AUTO 0 0 0 $stop $cn_nn $cn_seed"
   set cn_traffic="set-ping-int 1"
   set scen_config="set-scen NN_RAND $nb_site 0 $mt 0"

   # Input Directories
   set TOPOD={$MOBI}/topologies 	# Directory for topologies
 
   # Input Files
   set TOPOF={$TOPOD}/{$topo}.tcl	# topology file path
  
   # Output Directory
   set OUTDIR=.tmp
   echo "Output in temporary directory $OUTDIR"
   if ( -d $OUTDIR ) then
	rm -R $OUTDIR
   endif
   mkdir $OUTDIR
   set NAMF={$OUTDIR}/out.nam		# NAM file (optional)
   set TRACEF={$OUTDIR}/out.tr
   set INFOF={$OUTDIR}/out.info   

   # Launch simulation  
   $NS mipv6.tcl -mn_nn 1 -global ON -x 800 -y 800 -mactrace ON -topoman ALL -DISPLAY_INFO TRUE -DISPLAY_INPUT TRUE -cn_nn $cn_nn -cn_config "$cn_config" -cn_traffic "$cn_traffic" -bs_nn -bs_config "$bs_config" -mn_config "$mn_config" -scen_config "$scen_config" -stop $stop -topo_file $TOPOF -tracefile $TRACEF > $INFOF 

