Agent/MN set bs_forwarding_     0       ; # 1 if forwarding from previous BS

################################################################
# Main 
################################################################
proc main { } {
   global opt ns namf n tracef infof
   # set LIB TCL-LIB
   source set-def-options.tcl
   source ../ns-orig-src/tcl/mobility/timer.tcl

   #>--------------- Extract options from command line ---------------<
   Getopt	; # Get option from the command line	

   # Following allows to display information about scenario and topology 
   if { [info exists opt(DISPLAY_INFO)] && $opt(DISPLAY_INFO) == "TRUE" } {
	display "ON"
   }
   if { [info exists opt(DISPLAY_INPUT)] && $opt(DISPLAY_INPUT) == "TRUE" } {
	dinput "ON"
   }

   #>------------------------ Open stdout files ----------------------<
   if { [display?] } { 
	if { $opt(infofile) != "stdout" } { 
		set infof [open $opt(infofile) w]
	} else {
		set infof stdout 
	}
	#  Remind simulation parameters to user
   	DisplayCommandLine  
	display-param
   } 
   
   # I want the same configuration for several simulation sets
   expr int(srand($opt(seed)))

   #>---------------------- Simulator Settings ----------------------<
   set ns [new Simulator]

   # Do you want to trace all MAC packets ? 
   if  [info exists opt(mactrace)] {
	$ns node-config -macTrace $opt(mactrace) 
   }

   # Global mobility needs special settings:
   # normal interface (ALL) or dual (DUAL) 
   if { [info exists opt(global)] && $opt(global) == "ON" } {
	$ns node-config -net-iface-type "DUAL"
   }

   #>------------------------ Open trace files ----------------------<
   exec rm -f $opt(tracefile)
   set tracef [open $opt(tracefile) w]
   $ns trace-all $tracef
   $ns at $opt(record_interval) "$ns dump-trace $tracef $opt(record_interval) $opt(stop)"
   
   if { [display?] } { 
      $ns at $opt(record_interval) "$ns dump-trace $infof $opt(record_interval) $opt(stop)"
   }
   if { $opt(NAM) == 1 } {
        set namf [open $opt(namfile) w]
        $ns namtrace-all $namf
   }

   #>------------- Protocol and Topology Settings -------------------<
   if { [info exists opt(topoman)] && $opt(topoman) == "WIREDONLY"} {
	wired-topo-settings
   } else {
	topo-settings
   }

   load-config-cn $opt(cn_nn) $opt(cn_config_file) 
   load-scen $opt(scen_file)	
 
   #>----------------------- Run Simulation -------------------------<
   if { [display?] } { 
   	# $ns at 1 "counter 1"
        log-mn-movement
   }
   if { $opt(RUN) == "TRUE" } {
	if { [display?] } {
	   puts $infof "*** Starting Simulation at [exec date]"
	}
	# Do not forget last measure
	set stop [expr $opt(stop) + 0.01]
	$ns at $stop "finish"
	$ns run
	
   } elseif { $opt(NAM) == 1 } {
	$ns dump-topology $namf
        close $namf
        puts "running nam with $opt(namfile) ... "
        exec nam $opt(namfile) &
   }
}

################################################################
# End of Simulation
################################################################
proc finish { } {
  global tracef infof
  global ns namf opt
 
  # Dump the Binding Update List of MN and Binding Cache of HA
  set mobile [get_mobile_by_index 0]
  [$mobile set regagent_] dump
  [[$mobile set ha_] set regagent_] dump

  $ns flush-trace
  flush $tracef
  close $tracef

 if { $opt(NAM) == 1 } {
     close $namf
     puts "running nam with $opt(namfile) ... "
     exec nam $opt(namfile) &
  }
  if { [display?] } {
     if { $opt(infofile) != "stdout" } {
        flush $infof
        close $infof
     }
   }
   exit 0
}

main

